import { useState } from 'react'
import { Button, Flex, Modal, Radio, Form, Row, Col } from 'antd'
import { useDataFieldQuery } from '@/hooks/useQuery'
import AppProgressSteps from '@/components/AppProgressSteps'

export default function ButtonModal() {
  const { fieldOptions } = useDataFieldQuery()

  const [open, setOpen] = useState(false)

  const [current, setCurrent] = useState(0)
  const [form] = Form.useForm()
  const initialValues = {
    checked: '',
    rule: '1',
  }

  const checked = Form.useWatch('checked', form)

  const ruleOptions = [
    { label: '分号“;”', value: '1' },
    { label: '逗号“,”', value: '2' },
    { label: '空格“ ”', value: '3' },
    // { label: '特定字符', value: '4' },
    // { label: '前几个字符', value: '5' },
  ]

  const [step, setStep] = useState<number>(-1)

  const steps = [
    {
      title: '请选择数据拆分字段',
      content: (
        <Form.Item name="checked" rules={[{ required: true, message: '请选择数据拆分字段' }]}>
          <Radio.Group>
            <Row gutter={[10, 10]}>
              {fieldOptions.map((item) => (
                <Col span={6} key={item.value}>
                  <Radio value={item.value}>{item.label}</Radio>
                </Col>
              ))}
            </Row>
          </Radio.Group>
        </Form.Item>
      ),
    },
    {
      title: '配置处理规则',
      content: (
        <>
          <Form.Item label="数据拆分字段">{checked}</Form.Item>
          <Form.Item label="处理规则" name="rule" rules={[{ required: true, message: '请选择处理规则' }]}>
            <Radio.Group options={ruleOptions} />
          </Form.Item>
        </>
      ),
    },
    {
      title: '处理执行',
      content: (
        <>
          <p>数据拆分处理字段：{checked}</p>
          <Flex vertical align="center" style={{ marginTop: '20px' }}>
            <Button type="primary" onClick={() => setStep(3)}>
              开始处理
            </Button>
            <AppProgressSteps
              style={{ margin: '80px' }}
              current={step}
              items={[
                {
                  title: <>计算拆分字段</>,
                },
                {
                  title: <>数据库表增加拆分字段</>,
                },
                {
                  title: <>更新拆分字段</>,
                },
                {
                  title: <>更新原始字段</>,
                },
                {
                  title: (
                    <>
                      第五步
                      <br />
                      处理结果
                    </>
                  ),
                },
              ]}
            />
          </Flex>
        </>
      ),
    },
  ]

  return (
    <>
      <Button type="primary" onClick={() => setOpen(true)}>
        数据拆分
      </Button>
      <Modal
        title={steps[current].title}
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            {current > 0 && <Button onClick={() => setCurrent(current - 1)}>上一步</Button>}
            {current < steps.length - 1 && (
              <Button type="primary" onClick={() => setCurrent(current + 1)} disabled={!checked}>
                下一步
              </Button>
            )}
            {current === steps.length - 1 && (
              <Button type="primary" onClick={() => setOpen(false)}>
                关闭
              </Button>
            )}
          </Flex>
        }
        destroyOnClose
        width={800}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '20px 0' }}>
          <Form form={form} labelCol={{ span: 5 }} preserve={false} initialValues={initialValues}>
            {steps.map((item, index) => (
              <div key={index} hidden={current !== index} style={{ marginTop: '20px' }}>
                {item.content}
              </div>
            ))}
          </Form>
        </div>
      </Modal>
    </>
  )
}
